@@ -30,11 +30,14 @@
 #include <pcre.h>
 
 /*  D E F I N E S  ************************************************************/
-#define VERSION                       "0.3.0"
+#ifndef RELEASE
+#define RELEASE
+#endif
+#define VERSION                       "0.3.3"RELEASE
 #define SIG_ALRM                      60        /* Time between cxt and asset cleaning/printing */
 #define TCP_TIMEOUT                   300       /* When idle IP connections should be timed out */
 #define ASSET_TIMEOUT                 86400     /* Time befor an asset is deleted if no updates */
-#define BUCKET_SIZE                   1669
+#define BUCKET_SIZE                   31337
 #define SNAPLENGTH                    1604
 #define MAX_BYTE_CHECK                500000
 #define MAX_PKT_CHECK                 10
@@ -45,31 +48,6 @@
 #define ASSET_TYPE_OS                 0x02
 #define ASSET_TYPE_SERVICE            0x04
 
-/* Flags to set for enabling different OS Fingerprinting checks.
- * Make these compatible with TCP flags!*/
-#define CO_FIN                        0x01      /* Check FIN packets */
-#define CO_SYN                        0x02      /* Check SYN packets */
-#define CO_RST                        0x04      /* Check RST packets */
-// push                               0x08
-#define CO_SYNACK                     0x08      /* Check SYNACK packets */
-#define CO_ACK                        0x10      /* Check Stray-ACK packets */
-// urg                                0x20
-// ece                                0x40
-// cwr                                0x80
-#define CO_ICMP                       0x20      /* Check ICMP Packets */
-#define CO_UDP                        0x40      /* Check UDP Packets */
-#define CO_DHCP                       0x80      /* Check DHCP Packets */
-#define CO_OTHER                      0x7f      /* Check Other Packets - need a flag! */
-
-/* Flags to set for enabling different service/client checks */
-#define CS_TCP_SERVER                 0x01
-#define CS_TCP_CLIENT                 0x02
-#define CS_UDP_SERVICES               0x04  /* Currently implying server+client*/
-#define CS_UDP_CLIENT                 0x08
-#define CS_MAC                        0x10
-#define CS_ICMP                       0x20
-#define CS_ARP                        0x80
-
 #define ETHERNET_TYPE_IP              0x0800
 #define ETHERNET_TYPE_ARP             0x0806
 #define ETHERNET_TYPE_IPV6            0x86dd
@@ -511,6 +489,21 @@ typedef struct _mac_entry {
 } mac_entry;
 
 
+/* DHCP Fingerprint / Signature entry */
+typedef struct _dhcp_fp_entry {
+    char *os;                   /* OS genre */
+    char *desc;                 /* OS description */
+    char *vc;                   /* Vender Code */
+    uint8_t type;               /* DHCP type */
+    uint8_t ttl;                /* IP TTL */
+    uint8_t optcnt;             /* option count */
+    uint8_t opt[MAXOPT];        /* DHCP Options */
+    uint8_t optreqcnt;          /* request option counter (53) */
+    uint8_t optreq[MAXOPT];     /* request option counter  */
+    uint32_t line;              /* config file line */
+    struct _dhcp_fp_entry *next;
+} dhcp_fp_entry;
+
 /*
  * Structure for connections
  */
@@ -523,6 +516,7 @@ typedef struct _connection {
     uint64_t cxid;                /* connection id */
     uint8_t  reversed;            /* 1 if the connection is reversed */
     uint32_t af;                  /* IP version (4/6) AF_INET */
+    uint16_t hw_proto;            /* layer2 protocol */
     uint8_t  proto;               /* IP protocoll type */
     struct   in6_addr s_ip;       /* source address */
     struct   in6_addr d_ip;       /* destination address */
@@ -533,6 +527,7 @@ typedef struct _connection {
     uint64_t d_total_pkts;        /* total destination packets */
     uint64_t d_total_bytes;       /* total destination bytes */
     uint8_t  s_tcpFlags;          /* tcpflags sent by source */
+    uint8_t  __pad__;             /* pads struct to alignment */
     uint8_t  d_tcpFlags;          /* tcpflags sent by destination */
     uint8_t  check;               /* Flags spesifying checking */
     struct   _asset *c_asset;     /* pointer to src asset */
